@@ -4,9 +4,9 @@ package TableDataRole::Spec::Basic;
 use Role::Tiny;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-27'; # DATE
+our $DATE = '2023-11-24'; # DATE
 our $DIST = 'TableData'; # DIST
-our $VERSION = '0.2.4'; # VERSION
+our $VERSION = '0.2.5'; # VERSION
 
 ### constructor
 
@@ -78,6 +78,28 @@ sub each_row_hashref {
     return 1;
 }
 
+sub convert_row_arrayref_to_hashref {
+    my ($self, $row_arrayref) = @_;
+
+    my $row_hashref = {};
+    my @column_names = $self->get_column_names;
+    for my $i (0 .. $#column_names) {
+        $row_hashref->{ $column_names[$i] } = $row_arrayref->[$i];
+    }
+    $row_hashref;
+}
+
+sub convert_row_hashref_to_arrayref {
+    my ($self, $row_hashref) = @_;
+
+    my $row_arrayref = [];
+    my @column_names = $self->get_column_names;
+    for my $i (0 .. $#column_names) {
+        $row_arrayref->[$i] = $row_hashref->{ $column_names[$i] };
+    }
+    $row_arrayref;
+}
+
 1;
 # ABSTRACT: Basic interface for all TableData::* modules
 
@@ -93,7 +115,7 @@ TableDataRole::Spec::Basic - Basic interface for all TableData::* modules
 
 =head1 VERSION
 
-This document describes version 0.2.4 of TableDataRole::Spec::Basic (from Perl distribution TableData), released on 2023-08-27.
+This document describes version 0.2.5 of TableDataRole::Spec::Basic (from Perl distribution TableData), released on 2023-11-24.
 
 =head1 DESCRIPTION
 
@@ -331,6 +353,18 @@ Basically:
 
 See also L</each_row_arrayref> (a.k.a. L</each_item>).
 
+=head2 convert_row_arrayref_to_hashref
+
+Usage:
+
+ my $row_hashref = $td->convert_row_arrayref_to_hashref($row_arrayref);
+
+=head2 convert_row_hashref_to_arrayref
+
+Usage:
+
+ my $row_arrayref = $td->convert_row_hashref_to_arrayref($row_hashref);
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData>.
